@@ -6,4 +6,4 @@ class UsersEntityFormRenderer(EntityFormRenderer):
     __select__ = EntityFormRenderer.__select__ & match_user_groups("users")
 
     def relations_form(self, w, form):
-        return u""
+        return ""
